@@ -39,6 +39,8 @@ use File::Spec;
 use Config;
 use Alien::SDL::ConfigData;
 
+our $config = {};
+
 # Module::Build doesn't seem to have a way to use separate flags for separate
 # XS files, so here's the override that makes separate files build correctly:
 sub process_xs {
@@ -133,21 +135,19 @@ sub set_file_flags {
 
 	while ( my ( $subsystem, $param ) = each %build_systems ) {
 		my $sub_file = $self->notes('subsystems')->{$subsystem}{file}{to};
+		my $extra_compiler_flags = [
+			( split( ' ', $arch . $debug . $self->notes('sdl_cflags') ) ),
+			@{ $param->{defines} },
+		];
+		push(@{$extra_compiler_flags}, '-DUSE_THREADS') if defined $Config{usethreads};
+		push(@{$extra_compiler_flags}, '-fPIC')         if $^O ne 'MSWin32';
 		$file_flags{$sub_file} = {
-			extra_compiler_flags => [
-				( split( ' ', $arch . $debug . $self->notes('sdl_cflags') ) ),
-				@{ $param->{defines} },
-				(   defined $Config{usethreads}
-					? ( '-DUSE_THREADS', '-fPIC' )
-					: ('-fPIC')
-				),
-			],
+			extra_compiler_flags => $extra_compiler_flags,
 			extra_linker_flags => [
 				( split( ' ', $self->notes('sdl_libs') ) ),
 				@{ $param->{links} },
 			],
-			},
-			;
+		};
 	}
 	$self->notes( 'file_flags' => \%file_flags );
 }
